@@ -3,7 +3,7 @@ import re
 import sys
 from argparse import ArgumentParser
 from copy import deepcopy
-from os import getcwd, listdir, mkdir
+from os import getcwd, listdir, mkdir, remove
 from os.path import dirname, isdir, join, normpath, relpath, isfile
 from shutil import copy, copytree
 from tempfile import TemporaryDirectory
@@ -301,11 +301,13 @@ class PandocStyles:
         if MD_PREFLIGHT not in self.cfg:
             return
         new = []
+        if not isdir(join(self.temp_dir, MODIFIED_FILES)):
+            mkdir(join(self.temp_dir, MODIFIED_FILES))
         for f in self.cfg[MD_CURRENT_FILES]:
-            if not isfile(join(self.temp_dir, f)):
-                new.append(copy(f, self.temp_dir))
-            else:
-                new.append(f)
+            modified_file = join(self.temp_dir, MODIFIED_FILES, get_full_file_name(f))
+            if isfile(modified_file):
+                remove(modified_file)
+            new.append(copy(f, modified_file))
         self.cfg[MD_CURRENT_FILES] = new
         self._flight(MD_PREFLIGHT, "<files>", " ".join(f'"{x}"' for x in
                                                        self.cfg[MD_CURRENT_FILES]))
@@ -383,6 +385,12 @@ class PandocStyles:
         if original_template != template:
             template = file_write("new.template", template, self.temp_dir)
             self.cfg[MD_TEMPLATE] = template
+        # for html we need the styles.html file in addition
+        if self.cfg[TO_FMT] == HTML:
+            pc = run_process(
+                f'{PANDOC_CMD} --print-default-data-file=templates/styles.html', True)
+            if pc:
+                file_write("styles.html", pc.stdout, self.temp_dir)
 
     def _replace_in_output(self):
         """Replace text in the output with text given in the style definition"""
